@@ -1,18 +1,7 @@
 /*
- *  Copyright 2012  Sebastian Gottfried <sebastiangottfried@web.de>
+ *  SPDX-FileCopyrightText: 2012 Sebastian Gottfried <sebastiangottfried@web.de>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 
@@ -78,9 +67,9 @@ bool ResourceTemplateWidget::isValid() const
 Resource* ResourceTemplateWidget::templateResource() const
 {
     if (!m_useTemplateCheckbox->isChecked())
-        return 0;
+        return nullptr;
     if (!m_templatesView->selectionModel()->hasSelection())
-        return 0;
+        return nullptr;
     const QModelIndex index = m_templatesView->selectionModel()->currentIndex();
     QObject* const object = m_filteredResourcesModel->data(index, ResourceModel::DataRole).value<QObject*>();
     return qobject_cast<Resource*>(object);
