@@ -1,25 +1,13 @@
 /*
- *  Copyright 2016  Sebastian Gottfried <sebastian.gottfried@posteo.de>
+ *  SPDX-FileCopyrightText: 2016 Sebastian Gottfried <sebastian.gottfried@posteo.de>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "ktouchcontext.h"
 
 #include <QMenu>
 #include <QPointer>
-#include <QDialogButtonBox>
 #include <QQuickView>
 
 #include "application.h"
@@ -30,6 +18,7 @@
 #include "trainingconfigwidget.h"
 #include "core/lesson.h"
 
+#include <kxmlgui_version.h>
 #include <KActionCollection>
 #include <KStandardAction>
 #include <KHelpMenu>
@@ -45,7 +34,7 @@
 
 
 
-const QString keyboardKCMName = QStringLiteral("kcm_keyboard");
+const QString keyboardKCMName = QStringLiteral("plasma/kcms/systemsettings/kcm_keyboard");
 
 KTouchContext::KTouchContext(KMainWindow* mainWindow, QQuickView* view, QObject *parent) :
     QObject(parent),
@@ -144,7 +133,7 @@ void KTouchContext::showConfigDialog()
 
 void KTouchContext::configureShortcuts()
 {
-    KShortcutsDialog::configure(m_actionCollection, KShortcutsEditor::LetterShortcutsDisallowed, m_mainWindow);
+    KShortcutsDialog::showDialog(m_actionCollection, KShortcutsEditor::LetterShortcutsDisallowed, m_mainWindow);
 }
 
 void KTouchContext::showKeyboardKCM()
@@ -152,7 +141,7 @@ void KTouchContext::showKeyboardKCM()
     QPointer<KCMultiDialog> kcm = new KCMultiDialog(m_mainWindow);
 
     kcm->setWindowTitle(i18nc("@title:window", "Configure Keyboard"));
-    kcm->addModule(keyboardKCMName);
+    kcm->addModule(KPluginMetaData(keyboardKCMName));
     kcm->exec();
 
     delete kcm;
@@ -190,12 +179,5 @@ void KTouchContext::init()
 
 bool KTouchContext::testKCMAvailibility(const QString& name)
 {
-    KService::Ptr service = KService::serviceByStorageId(name + ".desktop");
-
-    if (!service)
-    {
-        return false;
-    }
-
-    return service->hasServiceType(QStringLiteral("KCModule")) && !service->noDisplay();
+    return KPluginMetaData(name).isValid();
 }
