@@ -9,7 +9,6 @@
 
 #include <KMainWindow>
 
-#include <QWeakPointer>
 #include <QQuickView>
 
 class KTouchContext;
@@ -22,7 +21,7 @@ class MainWindow : public KMainWindow
 {
     Q_OBJECT
 public:
-    explicit MainWindow(QWidget* parent = 0);
+    explicit MainWindow(QWidget* parent = nullptr);
     ~MainWindow() override;
 private:
     void init();
