@@ -1,18 +1,7 @@
 /*
- *  Copyright 2012  Sebastian Gottfried <sebastiangottfried@web.de>
+ *  SPDX-FileCopyrightText: 2012 Sebastian Gottfried <sebastiangottfried@web.de>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 
@@ -24,7 +13,7 @@ CategorizedResourceSortFilterProxyModel::CategorizedResourceSortFilterProxyModel
     KCategorizedSortFilterProxyModel(parent),
     m_resourceTypeFilter(ResourceModel::CourseItem | ResourceModel::KeyboardLayoutItem),
     m_invertedKeyboardLayoutNameFilter(false),
-    m_resourceModel(0)
+    m_resourceModel(nullptr)
 {
     setDynamicSortFilter(true);
 }
